aboutsummaryrefslogtreecommitdiffstats
path: root/src/c.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2010-04-08 20:09:16 +0000
committerDavid Robillard <d@drobilla.net>2010-04-08 20:09:16 +0000
commit55b6a3f313670d2cb13847d1f1b04fe3e4b21d63 (patch)
tree200b7dbe00107507e8111b07747bef2cd3f6a958 /src/c.cpp
parent9d9fa6162295f3813d20f7a3ad4e07ccd6087c3c (diff)
downloadresp-55b6a3f313670d2cb13847d1f1b04fe3e4b21d63.tar.gz
resp-55b6a3f313670d2cb13847d1f1b04fe3e4b21d63.tar.bz2
resp-55b6a3f313670d2cb13847d1f1b04fe3e4b21d63.zip
Tuplr -> Resp (RESource Processing).
git-svn-id: http://svn.drobilla.net/resp/resp@252 ad02d1e2-f140-0410-9f75-f8b11f17cedd
Diffstat (limited to 'src/c.cpp')
-rw-r--r--src/c.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/c.cpp b/src/c.cpp
index 563c2ba..7dbb6c2 100644
--- a/src/c.cpp
+++ b/src/c.cpp
@@ -1,18 +1,18 @@
/* Tuplr: A programming language
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
* Tuplr is free software: you can redistribute it and/or modify it under
* the terms of the GNU Affero General Public License as published by the
* Free Software Foundation, either version 3 of the License, or (at your
* option) any later version.
*
* Tuplr is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General
* Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
- * along with Tuplr. If not, see <http://www.gnu.org/licenses/>.
+ * along with Resp. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
@@ -22,7 +22,7 @@
#include <map>
#include <sstream>
#include <boost/format.hpp>
-#include "tuplr.hpp"
+#include "resp.hpp"
using namespace std;
using boost::format;
@@ -80,7 +80,7 @@ struct CEngine : public Engine {
: out(
"#include <stdint.h>\n"
"#include <stdbool.h>\n"
- "void* tuplr_gc_allocate(unsigned size, uint8_t tag);\n\n")
+ "void* resp_gc_allocate(unsigned size, uint8_t tag);\n\n")
{
}
@@ -157,7 +157,7 @@ struct CEngine : public Engine {
};
Engine*
-tuplr_new_c_engine()
+resp_new_c_engine()
{
return new CEngine();
}
@@ -1,18 +1,18 @@
-/* Tuplr: A programming language
+/* Resp: A programming language
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
@@ -1,18 +1,18 @@
* Copyright (C) 2008-2009 David Robillard <dave@drobilla.net>
*
- * Tuplr is free software: you can redistribute it and/or modify it under
+ * Resp is free software: you can redistribute it and/or modify it under
* the terms of the GNU Affero General Public License as published by the
* Free Software Foundation, either version 3 of the License, or (at your
@@ -1,18 +1,18 @@
* option) any later version.
*
- * Tuplr is distributed in the hope that it will be useful, but WITHOUT
+ * Resp is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General